==> PySettings-0.1.0.tar.gz: PySettings-0.1.0/pysettings/loaders.py <==
# Copyright (c) 2010, Robert Escriva
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#     * Redistributions of source code must retain the above copyright notice,
#       this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of this project nor the names of its contributors may
#       be used to endorse or promote products derived from this software
#       without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.


'''Utilities for creating settings from various places.
'''


import os

from pysettings import modules
from pysettings.settings import Settings


def mod_to_settings(module_name):
    '''Convert the string representation of a module to a Settings object.

        >>> s = mod_to_settings('testdata.modules.full')
        >>> s.INT
        42
        >>> s.TUPLE_TEST
        (1, 2, 3, 4, 5)

    '''
    module = modules.get_module(module_name)
    return Settings(modules.mod_to_dict(module))


def environ_module_to_settings(var_name):
    '''Load settings from the module in the environment variable ``var_name``.

        >>> os.environ['PYSETTINGS_TEST'] = 'testdata.modules.full'
        >>> s = environ_module_to_settings('PYSETTINGS_TEST')
        >>> s.INT
        42
        >>> s.TUPLE_TEST
        (1, 2, 3, 4, 5)

    '''
    module_name = os.environ[var_name]
    return mod_to_settings(module_name)

==> PySettings-0.1.90.tar.gz: PySettings-0.1.90/pysettings/loaders.py <==
# Copyright (c) 2010, Robert Escriva
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#     * Redistributions of source code must retain the above copyright notice,
#       this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of this project nor the names of its contributors may
#       be used to endorse or promote products derived from this software
#       without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.


'''Utilities for creating settings from various places.
'''


import os

import pysettings
from pysettings import modules


def mod_to_settings(module_name):
    '''Convert the string representation of a module to a Settings object.

    .. doctest::

       >>> s = mod_to_settings('testdata.modules.full')
       >>> s.INT
       42
       >>> s.TUPLE_TEST
       (1, 2, 3, 4, 5)

    '''
    module = modules.get_module(module_name)
    return pysettings.Settings(modules.mod_to_dict(module))


def environ_to_settings(prefix):
    '''Use environment variables starting with `prefix` as settings.

    The keys in the settings object will be the environment values stripped of
    `prefix`.

    .. doctest::

       >>> os.environ['PYSETTINGS_TEST'] = 'the test value'
       >>> os.environ['PYSETTINGS_VAR'] = 'some variable'
       >>> os.environ['PYSETTINGS_lowercase'] = 'no more screaming'
       >>> s = environ_to_settings('PYSETTINGS_')
       >>> s.TEST
       'the test value'
       >>> s.VAR
       'some variable'
       >>> s.lowercase
       'no more screaming'

    '''
    d = {}
    for key, value in os.environ.items():
        if key.startswith(prefix):
            d[key[len(prefix):]] = value
    return pysettings.Settings(d)
